@@ -1,5 +1,5 @@
 from nislmigrate.utility import permission_checker
-from nislmigrate.logging import logging_setup, migration_error
+from nislmigrate.logs import logging_setup, migration_error
 from nislmigrate.argument_handler import ArgumentHandler
 from nislmigrate.facades.facade_factory import FacadeFactory
 from nislmigrate.migration_facilitator import MigrationFacilitator
